@@ -8,7 +8,6 @@ import re
 from gi.repository import Adw, Gio
 from typing import Optional, Literal
 
-from ..lib.utils import terminal
 from ..lib.utils import get_random_string, url_is_valid, get_file_hash
 from ..providers.AppImageProvider import AppImageProvider, AppImageListElement
 from .Models import DownloadInterruptedException
@@ -164,7 +163,9 @@ class StaticFileUpdater(UpdateManager):
 
             match = re.search(sha_pattern, zsync_file_header)
             if match:
-                return match.group(1) != curr_version_hash
+                updatable = match.group(1) != curr_version_hash
+                logging.info('SHA-1 detected, app updatable: ' + str(updatable))
+                return updatable
 
         headers = StaticFileUpdater.get_url_headers(self.url)
         resp_cl = int(headers.get('content-length', '0'))
